@@ -64,7 +64,7 @@ class Database(core.Construct):
         
         database_engine (str): The engine of database you want to create
 
-        database_engine_version (str): The engine version of database you want to create. Leave blank to get the latest version of the selected database engine (MySQL 5.7, PostgreSQL 10). More info https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rds-database-instance.html#cfn-rds-dbinstance-engineversion
+        database_engine_version (str | DatabaseClusterEngine): The engine version of database you want to create. Leave blank to get the latest version of the selected database engine (MySQL 5.7, PostgreSQL 10). More info https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rds-database-instance.html#cfn-rds-dbinstance-engineversion
         
         database_cluster_parameters_group_name (str):  The name of the DB cluster parameter group to associate with this DB cluster. This parameter depends on the Database Engine version you previously selected. In case you leave blank the version use default.aurora-mysql5.7 or default.aurora-postgresql10. If this argument is omitted, default.aurora5.6 is used. If default.aurora5.6 is used, specifying aurora-mysql or aurora-postgresql for the Engine property might result in an error. More info https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rds-database-instance.html#cfn-rds-dbinstance-engineversion
         
@@ -85,6 +85,12 @@ class Database(core.Construct):
         character_set_name (str):  For supported engines, specifies the character set to associate with the DB instance (Not applicable to Aurora Cluster)
         
         oracle_license_is_byol (str):  Applicable only to Orcale instances. The default license model is LICENSE_INCLUDED, specify this param in case you want to have an Orcale BRING_YOUR_OWN_LICENSE licence model
+
+        s3_export_buckets (Optional[Sequence[IBucket]]): S3 buckets that you want to load data into. This feature is only supported by the Aurora database engine. This property must not be used if s3ExportRole is used. For MySQL: Default: - None
+
+        s3_import_buckets (Optional[Sequence[IBucket]]): S3 buckets that you want to load data from. This feature is only supported by the Aurora database engine. This property must not be used if s3ImportRole is used. For MySQL: Default: - None
+
+
     """
     @property
     def security_group(self):
@@ -155,6 +161,8 @@ class Database(core.Construct):
         tag_scheduler_uptime_skip="",
         character_set_name=None,
         oracle_license_is_byol=None,
+        s3_export_buckets=None,
+        s3_import_buckets=None,
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
@@ -287,7 +295,8 @@ class Database(core.Construct):
         # ~~~~~~~~~~~~~~~~
         # RDS Database engine
         # ~~~~~~~~~~~~~~~~
-        self._engine = self.get_engine(database_engine, database_engine_version)
+        self._engine = (self.get_engine(database_engine, database_engine_version)) if isinstance(database_engine_version, str) else database_engine_version
+
 
         # ~~~~~~~~~~~~~~~~
         # RDS Cluster
@@ -311,6 +320,8 @@ class Database(core.Construct):
                 preferred_maintenance_window="mon:03:00-mon:04:00",
                 parameter_group=my_parameter_group,
                 storage_encryption_key=encryption_key,
+                s3_export_buckets=s3_export_buckets,
+                s3_import_buckets=s3_import_buckets
             )
 
             # Conditionally create a cluster from a snapshot
